@@ -8,7 +8,7 @@ class VersionManager(object):
 
     # m_pkg_name = 'pandas-coder'
     m_pkg_name = 'pdcoder'
-    m_current_version = tuple('0.4.0'.split('.'))
+    m_current_version = tuple('0.5.0'.split('.'))
     m_version_re = re.compile(r'\((from versions: (.*?))\)')
 
     def has_updated(self) -> bool:
@@ -28,10 +28,11 @@ class VersionManager(object):
 
     def start_update(self):
         import sys
-        subprocess.Popen(
-            'pip install pdcoder -U  && python main.py && echo done', shell=True)
-        sys.exit(1)
-        # self._use_pip(['install', self.m_pkg_name, '-U'])
+        import os
+        os.system(
+            'pip install pdcoder -U  && python main.py')
+
+        # sys.exit()
 
     def _use_pip(self, cmds: List[str]):
         # cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
